summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPiotr Maziarz <piotrx.maziarz@linux.intel.com>2021-12-16 16:31:22 +0100
committerPiotr Maziarz <piotrx.maziarz@linux.intel.com>2022-01-13 19:27:53 +0100
commit68c7e542075319d57129467872fcbe98906f2b2c (patch)
tree470c3b70c290c083cacb29b714c1fc2ebf327c0c
parent961221a76814ffa0ecc92219ddf857579b0f7d54 (diff)
downloadacpica-68c7e542075319d57129467872fcbe98906f2b2c.tar.gz
iASL: NHLT: Rename linux specific strucures to DeviceInfo
Those structures aren't used by Linux drivers, and in other NHLT related tools they are called DeviceInfo.
-rw-r--r--source/common/dmtbdump2.c28
-rw-r--r--source/common/dmtbinfo2.c8
-rw-r--r--source/compiler/dttable2.c16
-rw-r--r--source/include/actbinfo.h4
-rw-r--r--source/include/actbl2.h10
-rw-r--r--source/tools/acpisrc/astable.c4
6 files changed, 35 insertions, 35 deletions
diff --git a/source/common/dmtbinfo2.c b/source/common/dmtbinfo2.c
index da6151f0c..88ab9df44 100644
--- a/source/common/dmtbinfo2.c
+++ b/source/common/dmtbinfo2.c
@@ -1379,19 +1379,19 @@ ACPI_DMTABLE_INFO AcpiDmTableInfoNhlt6[] =
ACPI_DMT_TERMINATOR
};
-/* Number of Linux-specific structures */
+/* Number of DeviceInfo structures */
ACPI_DMTABLE_INFO AcpiDmTableInfoNhlt7[] =
{
- {ACPI_DMT_UINT8, ACPI_NHLT7_OFFSET (StructureCount), "Linux-specific Count", 0},
+ {ACPI_DMT_UINT8, ACPI_NHLT7_OFFSET (StructureCount), "Device Info struct count", 0},
ACPI_DMT_TERMINATOR
};
-/* The Linux-specific structure */
+/* The DeviceInfo structure */
ACPI_DMTABLE_INFO AcpiDmTableInfoNhlt7a[] =
{
- {ACPI_DMT_BUF16, ACPI_NHLT7A_OFFSET (DeviceId), "Device ID", 0},
+ {ACPI_DMT_UUID, ACPI_NHLT7A_OFFSET (DeviceId), "Device ID GUID", 0},
{ACPI_DMT_UINT8, ACPI_NHLT7A_OFFSET (DeviceInstanceId), "Device Instance ID", 0},
{ACPI_DMT_UINT8, ACPI_NHLT7A_OFFSET (DevicePortId), "Device Port ID", 0},
ACPI_DMT_TERMINATOR
diff --git a/source/include/actbinfo.h b/source/include/actbinfo.h
index f25d8cc44..ff7c0c15e 100644
--- a/source/include/actbinfo.h
+++ b/source/include/actbinfo.h
@@ -343,8 +343,8 @@
#define ACPI_NHLT6_OFFSET(f) (UINT16) ACPI_OFFSET (ACPI_NHLT_VENDOR_MIC_CONFIG,f)
#define ACPI_NHLT6A_OFFSET(f) (UINT16) ACPI_OFFSET (ACPI_NHLT_VENDOR_MIC_COUNT,f)
#define ACPI_NHLT6B_OFFSET(f) (UINT16) ACPI_OFFSET (ACPI_NHLT_RENDER_FEEDBACK_DEVICE_SPECIFIC_CONFIG,f)
-#define ACPI_NHLT7_OFFSET(f) (UINT16) ACPI_OFFSET (ACPI_NHLT_LINUX_SPECIFIC_COUNT,f)
-#define ACPI_NHLT7A_OFFSET(f) (UINT16) ACPI_OFFSET (ACPI_NHLT_LINUX_SPECIFIC_DATA,f)
+#define ACPI_NHLT7_OFFSET(f) (UINT16) ACPI_OFFSET (ACPI_NHLT_DEVICE_INFO_COUNT,f)
+#define ACPI_NHLT7A_OFFSET(f) (UINT16) ACPI_OFFSET (ACPI_NHLT_DEVICE_INFO,f)
#define ACPI_NHLT9_OFFSET(f) (UINT16) ACPI_OFFSET (ACPI_NHLT_MIC_SNR_SENSITIVITY_EXTENSION,f)
#define ACPI_PCCT0_OFFSET(f) (UINT16) ACPI_OFFSET (ACPI_PCCT_SUBSPACE,f)
#define ACPI_PCCT1_OFFSET(f) (UINT16) ACPI_OFFSET (ACPI_PCCT_HW_REDUCED,f)
diff --git a/source/include/actbl2.h b/source/include/actbl2.h
index 7bbd39a44..923c814ca 100644
--- a/source/include/actbl2.h
+++ b/source/include/actbl2.h
@@ -2102,21 +2102,21 @@ typedef struct acpi_nhlt_render_feedback_device_specific_config
} ACPI_NHLT_RENDER_FEEDBACK_DEVICE_SPECIFIC_CONFIG;
-/* Linux-specific structures */
+/* Non documented structures */
-typedef struct acpi_nhlt_linux_specific_count
+typedef struct acpi_nhlt_device_info_count
{
UINT8 StructureCount;
-} ACPI_NHLT_LINUX_SPECIFIC_COUNT;
+} ACPI_NHLT_DEVICE_INFO_COUNT;
-typedef struct acpi_nhlt_linux_specific_data
+typedef struct acpi_nhlt_device_info
{
UINT8 DeviceId[16];
UINT8 DeviceInstanceId;
UINT8 DevicePortId;
-} ACPI_NHLT_LINUX_SPECIFIC_DATA;
+} ACPI_NHLT_DEVICE_INFO;
/*******************************************************************************
diff --git a/source/tools/acpisrc/astable.c b/source/tools/acpisrc/astable.c
index 51e3de726..9bf1aa726 100644
--- a/source/tools/acpisrc/astable.c
+++ b/source/tools/acpisrc/astable.c
@@ -856,8 +856,8 @@ ACPI_TYPED_IDENTIFIER_TABLE AcpiIdentifiers[] = {
{"ACPI_NHLT_ENDPOINT_COUNT", SRC_TYPE_STRUCT},
{"ACPI_NHLT_FORMAT_CONFIG", SRC_TYPE_STRUCT},
{"ACPI_NHLT_FORMATS_CONFIG", SRC_TYPE_STRUCT},
- {"ACPI_NHLT_LINUX_SPECIFIC_COUNT", SRC_TYPE_STRUCT},
- {"ACPI_NHLT_LINUX_SPECIFIC_DATA", SRC_TYPE_STRUCT},
+ {"ACPI_NHLT_DEVICE_INFO_COUNT", SRC_TYPE_STRUCT},
+ {"ACPI_NHLT_DEVICE_INFO", SRC_TYPE_STRUCT},
{"ACPI_NHLT_MIC_DEVICE_SPECIFIC_CONFIG", SRC_TYPE_STRUCT},
{"ACPI_NHLT_MIC_SNR_SENSITIVITY_EXTENSION",SRC_TYPE_STRUCT},
{"ACPI_NHLT_RENDER_DEVICE_SPECIFIC_CONFIG", SRC_TYPE_STRUCT},
diff --git a/source/common/dmtbdump2.c b/source/common/dmtbdump2.c
index 9c3e5700a..9f9fa0f73 100644
--- a/source/common/dmtbdump2.c
+++ b/source/common/dmtbdump2.c
@@ -1501,8 +1501,8 @@ AcpiDmDumpNhlt (
ACPI_NHLT_VENDOR_MIC_COUNT *MicCount;
ACPI_NHLT_DEVICE_SPECIFIC_CONFIG_A *DevSpecific;
ACPI_NHLT_FORMATS_CONFIG *FormatsConfig;
- ACPI_NHLT_LINUX_SPECIFIC_COUNT *Count;
- ACPI_NHLT_LINUX_SPECIFIC_DATA *LinuxData;
+ ACPI_NHLT_DEVICE_INFO_COUNT *Count;
+ ACPI_NHLT_DEVICE_INFO *DeviceInfo;
ACPI_NHLT_DEVICE_SPECIFIC_CONFIG_B *Capabilities;
@@ -1777,42 +1777,42 @@ AcpiDmDumpNhlt (
/*
* If we are not done with the current Endpoint yet, then there must be
- * some Linux-specific structure(s) yet to be processed. First, get
+ * some non documented structure(s) yet to be processed. First, get
* the count of such structure(s).
*/
if (Offset < EndpointEndOffset)
{
- AcpiOsPrintf ("\n /* Linux-specific structures (not part of NHLT spec) */\n");
- Count = ACPI_ADD_PTR (ACPI_NHLT_LINUX_SPECIFIC_COUNT, Table, Offset);
+ AcpiOsPrintf ("\n /* Structures that are not part of NHLT spec */\n");
+ Count = ACPI_ADD_PTR (ACPI_NHLT_DEVICE_INFO_COUNT, Table, Offset);
Status = AcpiDmDumpTable (TableLength, Offset, Count,
- sizeof (ACPI_NHLT_LINUX_SPECIFIC_COUNT), AcpiDmTableInfoNhlt7);
+ sizeof (ACPI_NHLT_DEVICE_INFO_COUNT), AcpiDmTableInfoNhlt7);
if (ACPI_FAILURE (Status))
{
return;
}
- Offset += sizeof (ACPI_NHLT_LINUX_SPECIFIC_COUNT);
+ Offset += sizeof (ACPI_NHLT_DEVICE_INFO_COUNT);
- /* Variable number of linux-specific structures */
+ /* Variable number of device structures */
for (j = 0; j < Count->StructureCount; j++)
{
- LinuxData = ACPI_ADD_PTR (ACPI_NHLT_LINUX_SPECIFIC_DATA, Table, Offset);
- AcpiOsPrintf ("\n /* Linux-specific structure #%u (not part of NHLT spec) */\n", j+1);
+ DeviceInfo = ACPI_ADD_PTR (ACPI_NHLT_DEVICE_INFO, Table, Offset);
+ AcpiOsPrintf ("\n /* Device Info structure #%u (not part of NHLT spec) */\n", j+1);
/*
* Dump the following Linux-specific fields:
* 1) Device ID
* 2) Device Instance ID
* 3) Device Port ID
*/
- Status = AcpiDmDumpTable (TableLength, Offset, LinuxData,
- sizeof (ACPI_NHLT_LINUX_SPECIFIC_DATA), AcpiDmTableInfoNhlt7a);
+ Status = AcpiDmDumpTable (TableLength, Offset, DeviceInfo,
+ sizeof (ACPI_NHLT_DEVICE_INFO), AcpiDmTableInfoNhlt7a);
if (ACPI_FAILURE (Status))
{
return;
}
- Offset += sizeof (ACPI_NHLT_LINUX_SPECIFIC_DATA);
+ Offset += sizeof (ACPI_NHLT_DEVICE_INFO);
}
/*
@@ -1777,42 +1777,42 @@ AcpiDmDumpNhlt (
/*
- * Dump the following Linux-specific fields:
+ * Dump the following Device Info fields:
* 1) Device ID
* 2) Device Instance ID
diff --git a/source/compiler/dttable2.c b/source/compiler/dttable2.c
index 81b2ed885..33a246dfb 100644
--- a/source/compiler/dttable2.c
+++ b/source/compiler/dttable2.c
@@ -807,7 +807,7 @@ DtCompileNhlt (
UINT32 CapabilitiesSize;
UINT8 ArrayType;
UINT8 ConfigType;
- UINT8 LinuxSpecificCount;
+ UINT8 DeviceInfoCount;
UINT32 i;
UINT32 j;
ACPI_TABLE_NHLT_ENDPOINT_COUNT *MainTable;
@@ -815,7 +815,7 @@ DtCompileNhlt (
ACPI_NHLT_VENDOR_MIC_COUNT *MicCount;
ACPI_NHLT_FORMATS_CONFIG *FormatsConfig;
ACPI_NHLT_DEVICE_SPECIFIC_CONFIG_D *ConfigSpecific;
- ACPI_NHLT_LINUX_SPECIFIC_COUNT *LinuxSpecific;
+ ACPI_NHLT_DEVICE_INFO_COUNT *DeviceInfo;
/* Main table */
@@ -1076,12 +1076,12 @@ DtCompileNhlt (
/*
* If we are not done with the current Endpoint yet, then there must be
- * some Linux-specific structure(s) yet to be processed. First, get
+ * some non documeneted structure(s) yet to be processed. First, get
* the count of such structure(s).
*/
if (*PFieldList && (strcmp ((const char *) (*PFieldList)->Name, "Descriptor Length")))
{
- /* Get the count of Linux-specific structures */
+ /* Get the count of non documented structures */
Status = DtCompileTable (PFieldList, AcpiDmTableInfoNhlt7,
&Subtable);
@@ -1093,13 +1093,13 @@ DtCompileNhlt (
ParentTable = DtPeekSubtable ();
DtInsertSubtable (ParentTable, Subtable);
- LinuxSpecific = ACPI_CAST_PTR (ACPI_NHLT_LINUX_SPECIFIC_COUNT, Subtable->Buffer);
- LinuxSpecificCount = LinuxSpecific->StructureCount;
+ DeviceInfo = ACPI_CAST_PTR (ACPI_NHLT_DEVICE_INFO_COUNT, Subtable->Buffer);
+ DeviceInfoCount = DeviceInfo->StructureCount;
- for (j = 0; j < LinuxSpecificCount; j++)
+ for (j = 0; j < DeviceInfoCount; j++)
{
/*
* Compile the following Linux-specific fields:
* 1) Device ID
* 2) Device Instance ID
* 3) Device Port ID
@@ -1093,13 +1093,13 @@ DtCompileNhlt (
{
/*
- * Compile the following Linux-specific fields:
+ * Compile the following Device Info fields:
* 1) Device ID
* 2) Device Instance ID